"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from) {
    for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
    return to;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveLocalAsset = void 0;
var path_1 = require("path");
var fs_1 = require("fs");
var js_yaml_1 = __importDefault(require("js-yaml"));
var findFile_1 = __importDefault(require("../util/findFile"));
var assets = {};
function resolveLocalAsset(portalPath, path) {
    if (!assets[path]) {
        var _a = path.split(/[\\\\/]/), portalName = _a[0], type = _a[1], recordPathParts = _a.slice(2);
        var basePath = path_1.join(portalPath, portalName, type);
        var asset = void 0;
        switch (type) {
            case "basic-forms":
                asset = resolveBasicForm(basePath, recordPathParts);
                break;
            case "advanced-forms":
                asset = resolveAdvancedForm(basePath, recordPathParts);
                break;
            default:
                throwUnsupportedAssetTypeError(type);
        }
        assets[path] = __assign({ portalName: portalName }, asset);
    }
    return assets[path];
}
exports.resolveLocalAsset = resolveLocalAsset;
function resolveBasicForm(basePath, recordPathParts) {
    var basicFormName = recordPathParts[0];
    var yamlFilePath = findFile_1.default(path_1.join(basePath, basicFormName, basicFormName + ".basicform.yml"));
    var javascriptFilePath = yamlFilePath.replace(/\.yml$/, ".custom_javascript.js");
    var contents = fs_1.readFileSync(yamlFilePath).toString();
    var basicForm = js_yaml_1.default.load(contents);
    return {
        entityLogicalName: "adx_entityform",
        contentAttribute: "adx_registerstartupscript",
        id: basicForm.adx_entityformid,
        contentFilePath: javascriptFilePath,
    };
}
function resolveAdvancedForm(basePath, recordPathParts) {
    if (recordPathParts.length === 0) {
        throwUnsupportedAssetTypeError("advanced-forms");
    }
    var formStepName = recordPathParts[2];
    var yamlFilePath = findFile_1.default(path_1.join.apply(void 0, __spreadArray(__spreadArray([basePath], recordPathParts), [formStepName + ".advancedformstep.yml"])));
    var javascriptFilePath = yamlFilePath.replace(/\.yml$/, ".custom_javascript.js");
    var contents = fs_1.readFileSync(yamlFilePath).toString();
    var advancedForm = js_yaml_1.default.load(contents);
    return {
        entityLogicalName: "adx_webformstep",
        contentAttribute: "adx_registerstartupscript",
        id: advancedForm.adx_webformstepid,
        contentFilePath: javascriptFilePath,
    };
}
function throwUnsupportedAssetTypeError(type) {
    throw new Error("Asset type " + type + " is not yet supported.");
}
